Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpredis/phpredis.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormichael-grunder <michael.grunder@gmail.com>2014-06-19 16:34:10 +0400
committermichael-grunder <michael.grunder@gmail.com>2015-05-06 01:02:04 +0300
commit4b3e05714922f6a89c261ab9ea5fe1d96386c554 (patch)
tree758119d2a6861da0bc3d975b90473823d90209e6 /cluster_library.h
parent36e78540a65bc00361f71b33c5af0fdd33131afd (diff)
DEL command implemented
Modified our MSET handler and made it generic (it has the same general mechanism as DEL, just with a different return type) and implemented the DEL command. We've got the same consideration to make. What to do in the event of a catastrophic failure.
Diffstat (limited to 'cluster_library.h')
-rw-r--r--cluster_library.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/cluster_library.h b/cluster_library.h
index 9eb2f0c0..61b73746 100644
--- a/cluster_library.h
+++ b/cluster_library.h
@@ -408,7 +408,9 @@ PHPAPI void cluster_multi_mbulk_resp(INTERNAL_FUNCTION_PARAMETERS,
PHPAPI zval *cluster_zval_mbulk_resp(INTERNAL_FUNCTION_PARAMETERS,
redisCluster *c, int pull, mbulk_cb cb);
-/* Handlers for things like MGET/MSET/MSETNX */
+/* Handlers for things like DEL/MGET/MSET/MSETNX */
+PHPAPI void cluster_del_resp(INTERNAL_FUNCTION_PARAMETERS,
+ redisCluster *c, void *ctx);
PHPAPI void cluster_mbulk_mget_resp(INTERNAL_FUNCTION_PARAMETERS,
redisCluster *c, void *ctx);
PHPAPI void cluster_mset_resp(INTERNAL_FUNCTION_PARAMETERS,